It is important that input sanitisation be conducted to prevent
application files (ASP, JSP, PHP or config files) from being called.
It is also important that the file system permissions are correctly
configured and that all unused files are removed from the web root.
If these are not an option, then the vulnerable file should be removed
from the server.